@@ -26,7 +26,7 @@ def _get_version(modname: str) -> str:
         return None
 
 
-def _get_dependency_versions(modnames: list) -> dict:
+def get_dependency_versions(modnames: list) -> dict:
     """
     This function re-implements the functionality of the 'private' `_get_deps_info()`
     function in sklearn:
@@ -41,7 +41,7 @@ def module_exists(modname: str) -> bool:
 
 
 def save_dependencies(tmp_dir: str, deps: list) -> str:
-    deps_info = _get_dependency_versions(deps)
+    deps_info = get_dependency_versions(deps)
     deps_info = {k: v for k, v in deps_info.items() if v is not None}
     return save_json(tmp_dir, _PYTHON_INFO_FILE, deps_info)
 
@@ -49,22 +49,3 @@ def save_dependencies(tmp_dir: str, deps: list) -> str:
 def save_model_info(tmp_dir, model_name: str, model_info: dict) -> str:
     model_info["name"] = model_name
     return save_json(tmp_dir, _MODEL_TYPE_FILE, model_info)
-
-
-def extract_dependencies(archive_path: str) -> dict:
-    return _extract_json(archive_path, _PYTHON_INFO_FILE)
-
-
-def extract_model_type(archive_path: str) -> dict:
-    return _extract_json(archive_path, _MODEL_TYPE_FILE)
-
-
-def _extract_json(archive_path: str, file_name: str) -> dict:
-    if not archive_path.endswith(".tar.gz"):
-        return {}
-    with tarfile.open(archive_path, "r:gz") as tar:
-        deps_info = tar.extractfile(file_name)
-        if deps_info is not None:
-            deps = deps_info.read()
-            return json.loads(deps)
-    return {}
