@@ -14,7 +14,6 @@
 import json
 import os
 import sys
-import tarfile
 
 from modelstore.meta import dependencies
 
@@ -47,7 +46,7 @@ def test_get_dependency_versions():
         "isort": "5.5.3",
         "a-missing-dependency": None,
     }
-    result = dependencies._get_dependency_versions(test_deps)
+    result = dependencies.get_dependency_versions(test_deps)
     assert result == expected
 
 
@@ -77,21 +76,3 @@ def test_save_dependencies(tmp_path):
     with open(tmp_file, "r") as lines:
         result = json.loads(lines.read())
     assert result == expected
-
-
-def test_extract_dependencies(tmp_path):
-    expected = {
-        "pytest": "6.0.1",
-        "pylint": "2.6.0",
-        "black": "19.10b0",
-        "flake8": "3.8.3",
-        "isort": "5.5.3",
-    }
-    tmp_archive = os.path.join(tmp_path, "archive.tar.gz")
-    tmp_file = dependencies.save_dependencies(tmp_path, expected)
-    assert os.path.split(tmp_file)[1] == "python-info.json"
-
-    with tarfile.open(tmp_archive, "w:gz") as tar:
-        tar.add(name=tmp_file, arcname=os.path.split(tmp_file)[1])
-    result = dependencies.extract_dependencies(tmp_archive)
-    assert result == expected
